@@ -50,7 +50,11 @@ MainSettings::MainSettings(QWidget *parent) : QWidget(parent)
     languageComboBox->setCurrentIndex(languageComboBox->findText(languageLocale.nativeLanguageName()));
 
     // Connect after we set the current language from settings.
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(languageComboBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &MainSettings::widgetModified);
+#else
+    connect(languageComboBox, static_cast<void (QComboBox::*)(int, const QString &)>(&QComboBox::currentIndexChanged) , this, &MainSettings::widgetModified);
+#endif
 
 #ifndef HAVE_SPEECH
     kcfg_enablePronunciation->hide();
@@ -85,7 +89,7 @@ void MainSettings::populateLanguageBox()
 
         // get the language name
         QString languageName = languageLocale.nativeLanguageName();
-        if (languageName.isEmpty() || languageName == QLatin1String("C"))
+        if (languageName.isEmpty() || languageName == QLatin1Char('C'))
         {
             languageName = i18nc("@item:inlistbox no language for that locale", "None");
         }
